## ---------------------------------------------------------------------
##
## Copyright (C) 2012 - 2015 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE at
## the top level of the deal.II distribution.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "8.2.1")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "8")
SET(DEAL_II_VERSION_MINOR "2")
SET(DEAL_II_VERSION_SUBMINOR "1")
SET(DEAL_II_VERSION "8.2.1")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "Release")
SET(DEAL_II_BUILD_TYPES "RELEASE")


#
# Information about the project location
#

SET(DEAL_II_CMAKE_MACROS_RELDIR "share/deal.II/cmake/Macros")
SET(DEAL_II_COMMON_RELDIR "share/deal.II/common")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/deal.II")
SET(DEAL_II_DOCHTML_RELDIR "share/doc/deal.II/html")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/deal.II/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "lib/cmake/deal.II")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_CMAKE_MACROS_RELDIR}/macro_deal_ii*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/c++")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fpic -Wall -Wpointer-arith -Wwrite-strings -Wsynth -Wsign-compare -Wswitch -Wno-unused-local-typedefs -Wno-long-long   -std=c++11 -O3 -DNDEBUG -Wall -Wno-unused-local-typedefs -std=c++11 -O3 -DNDEBUG -Wall -Wno-unused-local-typedefs -std=c++11 -Wno-long-long")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-Wa,--compress-debug-sections -g -g")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing -Wno-unused -O3 -DNDEBUG -O3 -DNDEBUG")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-rdynamic -Wl,-rpath,/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib -L/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib -lflapack -lfblas")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")


#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II;${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II/bundled")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/${DEAL_II_LIBRARY_RELDIR}/libdeal_II.a;/usr/lib64/libbz2.so;/usr/lib64/libz.so;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libpetsc.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libHYPRE.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libcmumps.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libdmumps.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libsmumps.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libzmumps.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libmumps_common.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libpord.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libscalapack.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libsundials_cvode.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libsundials_nvecserial.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libsundials_nvecparallel.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libumfpack.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libklu.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libcholmod.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libbtf.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libccolamd.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libcolamd.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libcamd.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libamd.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libsuitesparseconfig.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libflapack.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libfblas.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libparmetis.a;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libmetis.a;/usr/lib64/libX11.so;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libmpifort.a;gfortran;quadmath;m;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libmpicxx.a;/usr/lib/gcc/x86_64-redhat-linux/4.8.5/libstdc++.so;/home/builder/jenkins/F123-linux-release/external_projects/petsc_3.6_build/src/flow123d_release/lib/libmpi.a;pthread;rt;/usr/lib/gcc/x86_64-redhat-linux/4.8.5/libgcc_s.so;dl")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "general;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about library targets
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal_II")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "general;${DEAL_II_TARGET_RELEASE}")


#
# Feature configuration:
#

SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ARPACK OFF)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_WITH_BZIP2 ON)
SET(DEAL_II_WITH_CXX11 ON)
SET(DEAL_II_WITH_HDF5 OFF)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_WITH_METIS OFF)
SET(DEAL_II_WITH_MPI ON)
SET(DEAL_II_WITH_MUMPS OFF)
SET(DEAL_II_WITH_MUPARSER OFF)
SET(DEAL_II_WITH_NETCDF OFF)
SET(DEAL_II_WITH_OPENCASCADE OFF)
SET(DEAL_II_WITH_P4EST OFF)
SET(DEAL_II_WITH_PETSC ON)
SET(DEAL_II_WITH_SLEPC OFF)
SET(DEAL_II_WITH_THREADS OFF)
SET(DEAL_II_WITH_TRILINOS OFF)
SET(DEAL_II_WITH_UMFPACK OFF)
SET(DEAL_II_WITH_ZLIB ON)
